﻿using FluentValidation.AspNetCore;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Caching.Memory;
using Microsoft.Extensions.Options;
using Newtonsoft.Json.Linq;
using Performance.DtoModels;
using Performance.DtoModels.AppSettings;
using Performance.Infrastructure;
using Performance.Services;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Performance.Api.Controllers
{
    [Route("api/[controller]")]
    public class ConfigController : Controller
    {
        private ConfigService _configService;
        public ConfigController(ConfigService configService)
        {
            _configService = configService;
        }

        #region director
        /// <summary>
        /// 获取director列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        [Route("directorlist")]
        [HttpPost]
        public ApiResponse<List<DirectorResponse>> GetDireList([FromBody]ApiRequest request)
        {
            var list = _configService.GetDireList();
            return new ApiResponse<List<DirectorResponse>>(ResponseType.OK, "ok", list);
        }

        /// <summary>
        /// 添加数据 director
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        [Route("direinsert")]
        [HttpPost]
        public ApiResponse<DirectorResponse> DireInsert([FromBody]DirectorRequest request)
        {
            var director = _configService.DireInsert(request);
            return new ApiResponse<DirectorResponse>(ResponseType.OK, director);
        }

        /// <summary>
        /// 更新数据 director
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        [Route("direupdate")]
        [HttpPost]
        public ApiResponse<DirectorResponse> DireUpdate([CustomizeValidator(RuleSet = "Update"), FromBody]DirectorRequest request)
        {
            var director = _configService.DireUpdate(request);
            return new ApiResponse<DirectorResponse>(ResponseType.OK, director);
        }

        /// <summary>
        /// 删除数据 director
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        [Route("diredelete")]
        [HttpPost]
        public ApiResponse DireDelete([CustomizeValidator(RuleSet = "Delete"), FromBody]DirectorRequest request)
        {
            if (!_configService.DireDelete(request))
                return new ApiResponse(ResponseType.Fail);
            return new ApiResponse(ResponseType.OK);
        }
        #endregion

        #region drugprop
        [Route("drugproplist")]
        [HttpPost]
        public ApiResponse<List<DrugpropResponse>> GetDrugList([FromBody]ApiRequest request)
        {
            var list = _configService.GetDrugList();
            return new ApiResponse<List<DrugpropResponse>>(ResponseType.OK, "ok", list);
        }

        [Route("druginsert")]
        [HttpPost]
        public ApiResponse<DrugpropResponse> DrugInsert([FromBody]DrugpropRequest request)
        {
            var drugprop = _configService.DrugInsert(request);
            return new ApiResponse<DrugpropResponse>(ResponseType.OK, drugprop);
        }

        [Route("drugupdate")]
        [HttpPost]
        public ApiResponse<DrugpropResponse> Update([CustomizeValidator(RuleSet = "Update"), FromBody]DrugpropRequest request)
        {
            var drugprop = _configService.DrugUpdate(request);
            return new ApiResponse<DrugpropResponse>(ResponseType.OK, drugprop);
        }

        [Route("drugdelete")]
        [HttpPost]
        public ApiResponse Delete([CustomizeValidator(RuleSet = "Delete"), FromBody]DrugpropRequest request)
        {
            if (!_configService.DrugDelete(request))
                return new ApiResponse(ResponseType.Fail);
            return new ApiResponse(ResponseType.OK);
        }
        #endregion

        #region income
        [Route("incomelist")]
        [HttpPost]
        public ApiResponse<List<IncomeResponse>> GetIncomeList([FromBody]ApiRequest request)
        {
            var list = _configService.GetIncomeList();
            return new ApiResponse<List<IncomeResponse>>(ResponseType.OK, "ok", list);
        }

        [Route("incomeinsert")]
        [HttpPost]
        public ApiResponse<IncomeResponse> Insert([FromBody]IncomeRequest request)
        {
            var income = _configService.IncomeInsert(request);
            return new ApiResponse<IncomeResponse>(ResponseType.OK, income);
        }

        [Route("incomeupdate")]
        [HttpPost]
        public ApiResponse<IncomeResponse> Update([CustomizeValidator(RuleSet = "Update"), FromBody]IncomeRequest request)
        {
            var income = _configService.IncomeUpdate(request);
            return new ApiResponse<IncomeResponse>(ResponseType.OK, income);
        }

        [Route("incomedelete")]
        [HttpPost]
        public ApiResponse Delete([CustomizeValidator(RuleSet = "Delete"), FromBody]IncomeRequest request)
        {
            if (!_configService.IncomeDelete(request))
                return new ApiResponse(ResponseType.Fail);
            return new ApiResponse(ResponseType.OK);
        }
        #endregion

        #region workyear
        [Route("workyearlist")]
        [HttpPost]
        public ApiResponse<List<WorkyearResponse>> GetWorkList([FromBody]ApiRequest request)
        {
            var list = _configService.GetWorkList();
            return new ApiResponse<List<WorkyearResponse>>(ResponseType.OK, "ok", list);
        }

        [Route("workinsert")]
        [HttpPost]
        public ApiResponse<WorkyearResponse> WorkyearInsert([FromBody]WorkyearRequest request)
        {
            var workyear = _configService.WorkInsert(request);
            return new ApiResponse<WorkyearResponse>(ResponseType.OK, workyear);
        }

        [Route("workupdate")]
        [HttpPost]
        public ApiResponse<WorkyearResponse> WorkyearUpdate([CustomizeValidator(RuleSet = "Update"), FromBody]WorkyearRequest request)
        {
            var workyear = _configService.WorkUpdate(request);
            return new ApiResponse<WorkyearResponse>(ResponseType.OK, workyear);
        }

        [Route("workdelete")]
        [HttpPost]
        public ApiResponse WorkyearDelete([CustomizeValidator(RuleSet = "Delete"), FromBody]WorkyearRequest request)
        {
            if (!_configService.WorkDelete(request))
                return new ApiResponse(ResponseType.Fail);
            return new ApiResponse(ResponseType.OK);
        }
        #endregion
    }
}